@@ -37,6 +37,5 @@
  * POSSIBILITY OF SUCH DAMAGE.
  */
 
-void
-dump_dns(const u_char *payload, size_t paylen,
-	  FILE *trace, const char *endline);
+void dump_dns(const u_char* payload, size_t paylen,
+    FILE* trace, const char* endline);
